@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,8 +22,7 @@
 #include <KConfigGroup>
 #include "mailcommon_export.h"
 
-namespace MailCommon
-{
+namespace MailCommon {
 class AccountConfigOrderDialogPrivate;
 class MAILCOMMON_EXPORT AccountConfigOrderDialog : public QDialog
 {
@@ -32,13 +31,12 @@ public:
     explicit AccountConfigOrderDialog(QWidget *parent);
     ~AccountConfigOrderDialog();
 
-private Q_SLOTS:
+private:
     void slotOk();
     void slotMoveUp();
     void slotMoveDown();
     void slotEnableControls();
     void slotEnableAccountOrder(bool state);
-private:
     enum Type {
         IdentifierAccount = Qt::UserRole + 1
     };
